==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/dna_stat/transl/turkish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="14"/>
        <source>Generate Alignment Profile</source>
        <translation>Hizalama Profili Oluştur</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="20"/>
        <source>Profile mode</source>
        <translation>Profil modu</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="26"/>
        <source>Count</source>
        <translation>Miktar</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="36"/>
        <source>Percentage</source>
        <translation>Yüzde</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="46"/>
        <source>Custom options</source>
        <translation>Özel seçenekler</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="52"/>
        <source>Show scores for gaps</source>
        <translation>Boşluk puanlarını göster</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="59"/>
        <source>Show scores for symbols not used in alignment</source>
        <translation>Hizalamada kullanılmayan sembollerin puanlarını göster</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="66"/>
        <source>Skip gaps in consensus position increments</source>
        <translation>Konsensüs pozisyon artışlarındaki boşlukları atlayın</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="76"/>
        <source>Save profile to file</source>
        <translation>Profili dosyaya kaydedin</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="88"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="98"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="105"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Köprü metni  (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="115"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Virgülle ayrılmış ( .CSV)</translation>
    </message>
</context>
<context>
    <name>DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="14"/>
        <source>Generate Distance Matrix</source>
        <translation>Mesafe Matrisi Oluşturun</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="22"/>
        <source>Distance algorithm</source>
        <translation>Mesafe algoritması</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="34"/>
        <source>Profile mode</source>
        <translation>Profil modu</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="40"/>
        <source>Count</source>
        <translation>Miktar</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="50"/>
        <source>Percentage</source>
        <translation>Yüzde</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="57"/>
        <source>Exclude gaps</source>
        <translation>Boşlukları hariç tutun</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="67"/>
        <source>Show group statistics of multiple alignment</source>
        <translation>Çoklu hizalamanın grup istatistiklerini göster</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="77"/>
        <source>Save profile to file</source>
        <translation>Profili dosyaya kaydedin</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="89"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="99"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="106"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Köprü metni  (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="116"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Virgülle ayrılmış ( .CSV)</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="72"/>
        <source>Generate grid profile...</source>
        <translation>Izgara profili oluştur...</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="55"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="56"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="88"/>
        <source>Save file</source>
        <translation>Dosyayı kaydet</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="117"/>
        <source>File URL is empty</source>
        <translation>Dosya URL&apos;si boş</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileTask</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="129"/>
        <source>Generate alignment profile</source>
        <translation>Hizalama profili oluştur</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="142"/>
        <source>No output file name specified</source>
        <translation>Çıktı dosyası adı belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="179"/>
        <source>Alignment file:</source>
        <translation>Hizalama dosyası:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="181"/>
        <source>Table content:</source>
        <translation>Tablo içeriği:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="182"/>
        <source>symbol percents</source>
        <translation>sembol yüzdeleri</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="182"/>
        <source>symbol counts</source>
        <translation>sembol sayıları</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="152"/>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="279"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Dosya yazmak için açılamıyor: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="270"/>
        <source>There is not enough memory to show this grid profile in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>Bu ızgara profilini UGENE&apos;de göstermek için yeterli bellek yok. Bunu bir HTML dosyasına kaydedebilir ve bir web tarayıcısı ile açabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="272"/>
        <source>There is not enough memory to generate this grid profile in UGENE.</source>
        <translation>UGENE&apos;de bu ızgara profilini oluşturmak için yeterli bellek yok.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="312"/>
        <source>Task was finished with an error: %1</source>
        <translation>Görev bir hatayla tamamlandı: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="315"/>
        <source>Task was canceled.</source>
        <translation>Görev iptal edildi.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="319"/>
        <source>Grid profile for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>%1 için ızgara profili: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="333"/>
        <source>Alignment profile</source>
        <translation>Hizalama profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="333"/>
        <source>Alignment profile for %1</source>
        <translation>%1 için hizalama profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="176"/>
        <source>Multiple Sequence Alignment Grid Profile</source>
        <translation>Çoklu Sıra Hizalama Izgara Profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="252"/>
        <source>Legend:</source>
        <translation>Açıklama:</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatPlugin</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="53"/>
        <source>DNA Statistics</source>
        <translation>DNA İstatistikleri</translation>
    </message>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="53"/>
        <source>Provides statistical reports for sequences and alignments</source>
        <translation>Diziler ve hizalamalar için istatistiksel raporlar sağlar</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="110"/>
        <source>Generate distance matrix...</source>
        <translation>Mesafe matrisi oluştur...</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="61"/>
        <source>Generate</source>
        <translation>Oluştur</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="97"/>
        <source>Save file</source>
        <translation>Dosyayı kaydet</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>File URL is empty</source>
        <translation>Dosya URL&apos;si boş</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileTask</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="153"/>
        <source>Generate distance matrix</source>
        <translation>Mesafe matrisi oluştur</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="180"/>
        <source>No output file name specified</source>
        <translation>Çıktı dosyası adı belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="203"/>
        <source>Multiple Sequence Alignment Distance Matrix</source>
        <translation>Çoklu Sıra Hizalama Mesafe Matrisi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="206"/>
        <source>Alignment file:</source>
        <translation>Hizalama dosyası:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="207"/>
        <source>Table content:</source>
        <translation>Tablo içeriği:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="217"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="250"/>
        <source>There is not enough memory to show this distance matrix in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>Bu mesafe matrisini UGENE&apos;de göstermek için yeterli bellek yok. Bunu bir HTML dosyasına kaydedebilir ve bir web tarayıcısı ile açabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="224"/>
        <source>Group statistics of multiple alignment</source>
        <translation>Çoklu hizalamanın grup istatistikleri</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="256"/>
        <source>Legend:</source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="188"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="276"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Dosya yazmak için açılamıyor: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="317"/>
        <source>There is not enough groups to create distance matrix!</source>
        <translation>Uzaklık matrisi oluşturmak için yeterli grup yok!</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="369"/>
        <source>Task was finished with an error: %1</source>
        <translation>Görev bir hatayla tamamlandı: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="373"/>
        <source>Distanse matrix for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>%1 için mesafe matrisi: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="386"/>
        <source>Distance matrix</source>
        <translation>Mesafe matrisi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="386"/>
        <source>Distance matrix for %1</source>
        <translation>%1 için mesafe matrisi</translation>
    </message>
</context>
</TS>

==> ugene_51.0+dfsg.orig.tar.xz: ugene-51.0/src/plugins/dna_stat/transl/turkish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="14"/>
        <source>Generate Alignment Profile</source>
        <translation>Hizalama Profili Oluştur</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="20"/>
        <source>Profile mode</source>
        <translation>Profil modu</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="26"/>
        <source>Count</source>
        <translation>Miktar</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="36"/>
        <source>Percentage</source>
        <translation>Yüzde</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="46"/>
        <source>Custom options</source>
        <translation>Özel seçenekler</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="52"/>
        <source>Show scores for gaps</source>
        <translation>Boşluklar için puanları göster</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="59"/>
        <source>Show scores for symbols not used in alignment</source>
        <translation>Hizalamada kullanılmayan sembollerin puanlarını göster</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="66"/>
        <source>Skip gaps in consensus position increments</source>
        <translation>Konsensüs pozisyon artışlarındaki boşlukları atlayın</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="76"/>
        <source>Save profile to file</source>
        <translation>Profili dosyaya kaydedin</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="111"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="118"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="98"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Köprü metni  (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.ui" line="88"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Virgülle ayrılmış ( .CSV)</translation>
    </message>
</context>
<context>
    <name>DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="14"/>
        <source>Generate Distance Matrix</source>
        <translation>Mesafe Matrisi Oluşturun</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="22"/>
        <source>Distance algorithm</source>
        <translation>Mesafe algoritması</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="34"/>
        <source>Profile mode</source>
        <translation>Profil modu</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="40"/>
        <source>Count</source>
        <translation>Miktar</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="50"/>
        <source>Percentage</source>
        <translation>Yüzde</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="57"/>
        <source>Exclude gaps</source>
        <translation>Boşlukları hariç tutun</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="67"/>
        <source>Show group statistics of multiple alignment</source>
        <translation>Çoklu hizalamanın grup istatistiklerini göster</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="77"/>
        <source>Save profile to file</source>
        <translation>Profili dosyaya kaydedin</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="89"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="99"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="106"/>
        <source>Hypertext  (.HTML)</source>
        <translation>Köprü metni  (.HTML)</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.ui" line="116"/>
        <source>Comma separated ( .CSV)</source>
        <translation>Virgülle ayrılmış ( .CSV)</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="73"/>
        <source>Generate grid profile...</source>
        <translation>Izgara profili oluştur...</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileDialog</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="56"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="89"/>
        <source>Save file</source>
        <translation>Dosyayı kaydet</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="118"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="118"/>
        <source>File URL is empty</source>
        <translation>Dosya URL&apos;si boş</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="128"/>
        <source>&lt;b&gt;&lt;font color=%1&gt;%2&lt;/font&gt;&lt;br&gt;&lt;/br&gt;&lt;/b&gt;</source>
        <translation>&lt;b&gt;&lt;metin rengi=%1&gt;%2&lt;/font&gt;&lt;br&gt;&lt;/br&gt;&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="130"/>
        <source>Warning: report is too big to be shown in UGENE.</source>
        <translation>Uyarı: Rapor, UGENE&apos;de gösterilemeyecek kadar büyük.</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatMSAProfileTask</name>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="138"/>
        <source>Generate alignment profile</source>
        <translation>Hizalama profili oluştur</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="151"/>
        <source>No output file name specified</source>
        <translation>Çıktı dosyası adı belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="188"/>
        <source>Alignment file:</source>
        <translation>Hizalama dosyası:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="190"/>
        <source>Table content:</source>
        <translation>Tablo içeriği:</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="191"/>
        <source>symbol percents</source>
        <translation>sembol yüzdeleri</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="191"/>
        <source>symbol counts</source>
        <translation>sembol sayıları</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="161"/>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="288"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Dosya yazmak için açılamıyor: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="279"/>
        <source>There is not enough memory to show this grid profile in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>Bu ızgara profilini UGENE&apos;de göstermek için yeterli bellek yok. Bunu bir HTML dosyasına kaydedebilir ve bir web tarayıcısı ile açabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="281"/>
        <source>There is not enough memory to generate this grid profile in UGENE.</source>
        <translation>UGENE&apos;de bu ızgara profilini oluşturmak için yeterli bellek yok.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="321"/>
        <source>Task was finished with an error: %1</source>
        <translation>Görev bir hatayla tamamlandı: %1</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="324"/>
        <source>Task was canceled.</source>
        <translation>Görev iptal edildi.</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="328"/>
        <source>Grid profile for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>%1 için ızgara profili: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="342"/>
        <source>Alignment profile</source>
        <translation>Hizalama profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="342"/>
        <source>Alignment profile for %1</source>
        <translation>%1 için hizalama profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="185"/>
        <source>Multiple Sequence Alignment Grid Profile</source>
        <translation>Çoklu Sıra Hizalama Izgara Profili</translation>
    </message>
    <message>
        <location filename="../src/DNAStatMSAProfileDialog.cpp" line="261"/>
        <source>Legend:</source>
        <translation>Açıklama:</translation>
    </message>
</context>
<context>
    <name>U2::DNAStatPlugin</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="54"/>
        <source>DNA Statistics</source>
        <translation>DNA İstatistikleri</translation>
    </message>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="54"/>
        <source>Provides statistical reports for sequences and alignments</source>
        <translation>Diziler ve hizalamalar için istatistiksel raporlar sağlar</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAEditorContext</name>
    <message>
        <location filename="../src/DNAStatPlugin.cpp" line="114"/>
        <source>Generate distance matrix...</source>
        <translation>Mesafe matrisi oluştur...</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileDialog</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="61"/>
        <source>Generate</source>
        <translation>Oluştur</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="62"/>
        <source>Cancel</source>
        <translation>Vazgeç</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="97"/>
        <source>Save file</source>
        <translation>Dosyayı kaydet</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="128"/>
        <source>File URL is empty</source>
        <translation>Dosya URL&apos;si boş</translation>
    </message>
</context>
<context>
    <name>U2::DistanceMatrixMSAProfileTask</name>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="153"/>
        <source>Generate distance matrix</source>
        <translation>Mesafe matrisi oluştur</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="180"/>
        <source>No output file name specified</source>
        <translation>Çıktı dosyası adı belirtilmedi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="203"/>
        <source>Multiple Sequence Alignment Distance Matrix</source>
        <translation>Çoklu Sıra Hizalama Mesafe Matrisi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="206"/>
        <source>Alignment file:</source>
        <translation>Hizalama dosyası:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="207"/>
        <source>Table content:</source>
        <translation>Tablo içeriği:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="217"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="250"/>
        <source>There is not enough memory to show this distance matrix in UGENE. You can save it to an HTML file and open it with a web browser.</source>
        <translation>Bu mesafe matrisini UGENE&apos;de göstermek için yeterli bellek yok. Bunu bir HTML dosyasına kaydedebilir ve bir web tarayıcısı ile açabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="224"/>
        <source>Group statistics of multiple alignment</source>
        <translation>Çoklu hizalamanın grup istatistikleri</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="256"/>
        <source>Legend:</source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="188"/>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="276"/>
        <source>Can&apos;t open file for write: %1</source>
        <translation>Dosya yazmak için açılamıyor: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="317"/>
        <source>There is not enough groups to create distance matrix!</source>
        <translation>Uzaklık matrisi oluşturmak için yeterli grup yok!</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="369"/>
        <source>Task was finished with an error: %1</source>
        <translation>Görev bir hatayla tamamlandı: %1</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="373"/>
        <source>Distanse matrix for %1: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</source>
        <translation>%1 için mesafe matrisi: &lt;a href=&apos;%2&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="386"/>
        <source>Distance matrix</source>
        <translation>Mesafe matrisi</translation>
    </message>
    <message>
        <location filename="../src/DistanceMatrixMSAProfileDialog.cpp" line="386"/>
        <source>Distance matrix for %1</source>
        <translation>%1 için mesafe matrisi</translation>
    </message>
</context>
</TS>
